%define 	add_to_doc_files()	\
	mkdir -p %{buildroot}%{_docdir}/%{name}-%{version} ||: ; \
	cp -p %1  %{buildroot}%{_docdir}/%{name}-%{version}/$(echo '%1' | sed -e 's!/!.!g')

## Optional build modifications...
## --with 3dtransforms: Enables support for 3-D transforms.
##	(Default: No)
##
## --with coverage: Enables compile-time checking of code coverage.
##	(Default: No)
##
## --with debug: Enable more verbose debugging. Makes runtime a bit slower.
##	Also disables the optimized memory allocator.
##	(Default: No)
##
## --with pango: Use Pango instead of freetype2 as the font renderer.
##	CJK support is functional only with the freetype2 backend.
##	(Default: No - use freetype2)
##
## --with svg: Experimental SVG support (filters)
##	(Default: No) 
##
## --with wml: Build support for WML
##	(Default: No)

%bcond_with 	3dtransforms	
%bcond_with 	coverage	
%bcond_with 	debug
%bcond_with 	pango		
%bcond_with 	svg		
%bcond_with 	wml		

Distribution:	CCux
Packager:	Christian Metzen <metzench@ccux-linux.de>

Name:		webkitgtk
Version:	1.3.4
Release:	1
BuildArch:	i686
Summary:	GTK+ Web content engine library
Group:		Development/Libraries
License:	LGPLv2+ and BSD
URL:		http://www.webkitgtk.org/
Source0:	http://www.webkitgtk.org/webkit-%{version}.tar.gz
Patch2: 	webkit-1.3.1-nspluginwrapper.patch
Patch3:		webkit-python26.patch
BuildRequires:	bison
BuildRequires:	chrpath
BuildRequires:	flex
BuildRequires:	geoclue-devel
BuildRequires:	gettext
BuildRequires:	gperf
BuildRequires:	pcre-devel
BuildRequires:	gnutls-devel libtasn1-devel libgcrypt-devel libgpg-error-devel which

BuildRequires: libxcb-devel
BuildRequires: xcb-util-devel

BuildRequires: python26-devel
BuildRequires: python26

BuildRequires:  gobject-introspection-devel
BuildRequires:  libffi-devel
BuildRequires:  libXxf86vm-devel
BuildRequires:  libXdamage-devel

BuildRequires:	pango-devel
BuildRequires:	cairo-devel
BuildRequires:	fontconfig-devel
BuildRequires:	freetype-devel

#Automatically resolved build dependencies
BuildRequires: atk-devel
BuildRequires: enchant-devel
BuildRequires: glibc-devel
BuildRequires: glib-devel
BuildRequires: gst-plugins-base-devel
BuildRequires: gstreamer10-devel
BuildRequires: gtk2+-devel
BuildRequires: libgcc
BuildRequires: libICE-devel
BuildRequires: libicu-devel
BuildRequires: libjpeg-devel
BuildRequires: libpng-devel
BuildRequires: libSM-devel
BuildRequires: libsoup-devel
BuildRequires: libstdc++-devel
BuildRequires: libX11-devel
BuildRequires: libxml2-devel
BuildRequires: libxslt-devel
BuildRequires: libXt-devel
BuildRequires: pkg-config
BuildRequires: sqlite-devel
BuildRequires: zlib-devel

%description
WebKitGTK+ is the port of the portable web rendering engine WebKit to the
GTK+ platform.

%package	devel
Summary:	Development files for %{name}
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	pkgconfig
Requires:	gtk2+-devel

%description	devel
The %{name}-devel package contains libraries, build data, and header
files for developing applications that use %{name}.


%package	doc
Summary:	Documentation for %{name}
Group:		Documentation
Provides:	WebKit-doc = %{version}-%{release}
Obsoletes:	WebKit-doc < %{version}-%{release}

%description	doc
This package contains the documentation for %{name}, including various
LICENSE, README, and AUTHORS files.


%prep
%setup -qn "webkit-%{version}"
# %patch0 -p1 -b .atomic-word
# %patch1 -p1 -b .no-execmem
%patch2 -p1 -b .nspluginwrapper
%patch3 -p1

%build
CFLAGS="%optflags -DLIBSOUP_I_HAVE_READ_BUG_594377_AND_KNOW_SOUP_PASSWORD_MANAGER_MIGHT_GO_AWAY" %configure							\
			--disable-jit				\
			--enable-geolocation			\
			--enable-introspection			\
%{?with_3dtransforms:	--enable-3D-transforms		}	\
%{?with_coverage:	--enable-coverage		}	\
%{?with_debug:		--enable-debug			}	\
%{?with_pango:		--with-font-backend=pango	}	\
%{?with_svg:		--enable-svg-filters		}	\
%{?with_wml:		--enable-wml			}	\
			PYTHON=/usr/bin/python2.6

make


%install
rm -rf %{buildroot}

make install DESTDIR=%{buildroot}

chrpath --delete Programs/GtkLauncher
install -d -m 755 %{buildroot}%{_libexecdir}/%{name}
install -m 755 Programs/GtkLauncher %{buildroot}%{_libexecdir}/%{name}

## Finally, copy over and rename the various files for %%doc inclusion.
%add_to_doc_files JavaScriptCore/icu/LICENSE
%add_to_doc_files WebKit/LICENSE
%add_to_doc_files WebCore/icu/LICENSE
%add_to_doc_files WebCore/LICENSE-APPLE
%add_to_doc_files WebCore/LICENSE-LGPL-2
%add_to_doc_files WebCore/LICENSE-LGPL-2.1

%add_to_doc_files JavaScriptCore/pcre/COPYING
%add_to_doc_files JavaScriptCore/COPYING.LIB

%add_to_doc_files JavaScriptCore/icu/README
%add_to_doc_files WebKit/gtk/po/README

%add_to_doc_files JavaScriptCore/AUTHORS
%add_to_doc_files JavaScriptCore/pcre/AUTHORS

%add_to_doc_files JavaScriptCore/THANKS

%add_to_doc_files WebKit/gtk/NEWS


%clean
rm -rf %{buildroot}


%post	-p /sbin/ldconfig

%postun	-p /sbin/ldconfig


%files
%defattr(-,root,root,-)
%{_bindir}/jsc-1
%{_libdir}/girepository-1.0/JSCore-1.0.typelib
%{_libdir}/girepository-1.0/WebKit-1.0.typelib
%{_libdir}/libwebkitgtk-1.0.so.*
%{_datadir}/gir-1.0/JSCore-1.0.gir
%{_datadir}/gir-1.0/WebKit-1.0.gir
%{_datadir}/glib-2.0/schemas/org.webkitgtk-1.0.gschema.xml
%{_locale}/*/LC_MESSAGES/webkit-2.0.mo
%{_datadir}/webkit-1.0
%{_datadir}/webkitgtk-1.0
%{_prefix}/libexec/webkitgtk/GtkLauncher

%files	devel
%defattr(-,root,root,-)
%{_includedir}/webkit-1.0
%{_libdir}/libwebkitgtk-1.0.la
%{_libdir}/libwebkitgtk-1.0.so
%{_pkgconfig}/webkit-1.0.pc

%files	doc
%defattr(-,root,root,-)
%{_docdir}/%{name}-%{version}/

%changelog
* Tue Sep 28 2010 Karsten Brockmann <arcam@ccux-linux.de> 1.3.4-1
- Version update
* Tue Jun 08 2010 Karsten Brockmann <arcam@ccux-linux.de> 1.3.1-1
- Version update
* Tue Jan 19 2010 Karsten Brockmann <arcam@ccux-linux.de> 1.1.15.4-1
- Version update
* Tue Nov 24 2009 Christian Metzen <metzench@ccux-linux.de> 1.1.15.3-1
- Initial CCux package release
